
## CATO-CLI - mutation.policy.appTenantRestriction.discardPolicyRevision:
[Click here](https://api.catonetworks.com/documentation/#mutation-discardPolicyRevision) for documentation on this operation.

### Usage for mutation.policy.appTenantRestriction.discardPolicyRevision:

`catocli mutation policy appTenantRestriction discardPolicyRevision -h`

`catocli mutation policy appTenantRestriction discardPolicyRevision <json>`

`catocli mutation policy appTenantRestriction discardPolicyRevision "$(cat < discardPolicyRevision.json)"`

`catocli mutation policy appTenantRestriction discardPolicyRevision '{"appTenantRestrictionPolicyMutationInput": {"policyMutationRevisionInput": {"id": {"id": "ID"}}}, "policyDiscardRevisionInput": {"id": {"id": "ID"}}}'`

#### Operation Arguments for mutation.policy.appTenantRestriction.discardPolicyRevision ####
`accountId` [ID] - (required) N/A 
`appTenantRestrictionPolicyMutationInput` [AppTenantRestrictionPolicyMutationInput] - (optional) N/A 
`policyDiscardRevisionInput` [PolicyDiscardRevisionInput] - (optional) N/A 
